@@ -2,7 +2,7 @@ var test = require('../../');
 var path = require('path');
 
 test.createStream({ objectMode: true }).on('data', function (row) {
-    console.log(JSON.stringify(row))
+    console.log(JSON.stringify(row));
 });
 
 process.argv.slice(2).forEach(function (file) {
