@@ -6,7 +6,7 @@ module.exports = function () {
     var stream = through(write, flush);
     return stream;
 
-    function write (buf) {
+    function write(buf) {
         for (var i = 0; i < buf.length; i++) {
             var c = typeof buf === 'string'
                 ? buf.charAt(i)
@@ -17,13 +17,13 @@ module.exports = function () {
         }
     }
 
-    function flush () {
+    function flush() {
         if (fs.writeSync && /^win/.test(process.platform)) {
             try { fs.writeSync(1, line + '\n'); }
-            catch (e) { stream.emit('error', e) }
+            catch (e) { stream.emit('error', e); }
         } else {
-            try { console.log(line) }
-            catch (e) { stream.emit('error', e) }
+            try { console.log(line); }
+            catch (e) { stream.emit('error', e); }
         }
         line = '';
     }
