@@ -1,5 +1,5 @@
 var test = require('../../');
 
 for (var i = 0; i < 11; i ++) {
-    test(function (t) { t.ok(true, 'true is truthy'); t.end() });
+    test(function (t) { t.ok(true, 'true is truthy'); t.end(); });
 }
