@@ -5,11 +5,11 @@ tap.test('only twice error', function (assert) {
     var test = tape.createHarness({ exit : false });
 
     test.only("first only", function (t) {
-        t.end()
+        t.end();
     });
 
-    assert.throws(function() {
-        test.only('second only', function(t) {
+    assert.throws(function () {
+        test.only('second only', function (t) {
             t.end();
         });
     }, {
