@@ -20,26 +20,26 @@ tap.test('tape only test', function (tt) {
         ].join('\n') + '\n');
         tt.deepEqual(ran, [ 3 ]);
 
-        tt.end()
+        tt.end();
     };
 
     test.createStream().pipe(concat(tc));
 
     test("never run fail", function (t) {
         ran.push(1);
-        t.equal(true, false)
-        t.end()
-    })
+        t.equal(true, false);
+        t.end();
+    });
 
     test("never run success", function (t) {
         ran.push(2);
-        t.equal(true, true)
-        t.end()
-    })
+        t.equal(true, true);
+        t.end();
+    });
 
     test.only("run success", function (t) {
         ran.push(3);
-        t.ok(true, "assert name")
-        t.end()
-    })
-})
+        t.ok(true, "assert name");
+        t.end();
+    });
+});
